/*
   +----------------------------------------------------------------------+
   | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | https://www.php.net/license/3_01.txt                                 |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Stig Sæther Bakken <ssb@php.net>                             |
   +----------------------------------------------------------------------+
*/

#define CONFIGURE_COMMAND " './configure'  '--with-layout=GNU' '--with-apxs2=/usr/bin/apxs' '--with-config-file-path=/etc' '--disable-cgi' '--with-openssl' '--with-zlib' '--enable-bcmath' '--with-bz2' '--enable-calendar' '--enable-exif' '--enable-ftp' '--with-gmp' '--enable-intl' '--with-ldap' '--with-gettext' '--with-mysqli' '--with-pdo-mysql=mysqlnd' '--with-curl=/usr' '--with-jpeg=/usr' '--with-freetype=/usr' '--with-pgsql=/usr' '--with-readline=/usr' '--with-xsl' '--with-iconv' '--enable-mbstring=all' '--enable-mbregex' '--enable-soap' '--enable-pcntl' '--with-pear' '--enable-gd' '--with-zip' '--with-webp' 'build_alias=x86_64-linux-gnu'"
#define PHP_PROG_SENDMAIL	"/usr/bin/sendmail"
#define PEAR_INSTALLDIR         "/usr/share/pear"
#define PHP_INCLUDE_PATH	".:/usr/share/pear"
#define PHP_EXTENSION_DIR       "/usr/lib/php/20250925-zts"
#define PHP_PREFIX              "/usr"
#define PHP_BINDIR              "/usr/bin"
#define PHP_SBINDIR             "/usr/bin"
#define PHP_MANDIR              "/usr/share/man"
#define PHP_LIBDIR              "/usr/lib/php"
#define PHP_DATADIR             "/usr/share/php"
#define PHP_SYSCONFDIR          "/etc"
#define PHP_LOCALSTATEDIR       "/var"
#define PHP_CONFIG_FILE_PATH    "/etc"
#define PHP_CONFIG_FILE_SCAN_DIR    ""
#define PHP_SHLIB_SUFFIX        "so"
#define PHP_SHLIB_EXT_PREFIX    ""
